### Dienen
Build complex deep learning models using configuration files.

##### Installation
First of all you need to have tensorflow with gpu working in your system. You should be able to run nvidia-smi and get information about your GPUs.

Then, install using pip

```
pip install dienen
```

Now, that dienen is installed, it is time to train some models. Check out the [tutorial](docs/tutorial.md) and learn how to do it.
